pub struct Builder { /* private fields */ }Expand description
Builder for the WebSocket plugin, used to configure a custom TLS Connector before calling Builder::build.
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn tls_connector(self, connector: Connector) -> Self
pub fn tls_connector(self, connector: Connector) -> Self
Sets the TLS Connector used to establish wss:// connections.
When this is not called (or is called with Connector::Plain) and a rustls-tls or
rustls-tls-native-roots feature is enabled, Builder::build installs rustls’s ring
crypto provider as the process default if none is installed yet.
Sourcepub fn build<R: Runtime>(self) -> TauriPlugin<R>
pub fn build<R: Runtime>(self) -> TauriPlugin<R>
Builds the plugin, registering the connect and send commands and the shared connection state.